/*******************************************************************************
* File Name: C_Inv.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "C_Inv.h"


/*******************************************************************************
* Function Name: C_Inv_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void C_Inv_Write(uint8 value) 
{
    uint8 staticBits = C_Inv_DR & ~C_Inv_MASK;
    C_Inv_DR = staticBits | ((value << C_Inv_SHIFT) & C_Inv_MASK);
}


/*******************************************************************************
* Function Name: C_Inv_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void C_Inv_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(C_Inv_0, mode);
}


/*******************************************************************************
* Function Name: C_Inv_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro C_Inv_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 C_Inv_Read(void) 
{
    return (C_Inv_PS & C_Inv_MASK) >> C_Inv_SHIFT;
}


/*******************************************************************************
* Function Name: C_Inv_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 C_Inv_ReadDataReg(void) 
{
    return (C_Inv_DR & C_Inv_MASK) >> C_Inv_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(C_Inv_INTSTAT) 

    /*******************************************************************************
    * Function Name: C_Inv_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 C_Inv_ClearInterrupt(void) 
    {
        return (C_Inv_INTSTAT & C_Inv_MASK) >> C_Inv_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
